#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_MAP_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_MAP_HPP_INCLUDED

#include <boost/simd/operator/include/functions/map.hpp>

#endif
